# copyright 2012 CreaLibre (Monterrey, MEXICO), all rights reserved.
# contact http://www.crealibre.com/ -- mailto:info@crealibre.com

"""
"""
STYLESHEETS = [data('css/bootstrap.min.css'),
#               data('css/bootstrap-responsive.min.css'),
               data('css/custom.css'),
               data('cubes.bootstrap.css'),
               ]
JAVASCRIPTS.append(data('js/bootstrap.min.js'))
